==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/lingoes_ldf.md <==
## Lingoes Source (.ldf)

### General Information

| Attribute       | Value                                                               |
| --------------- | ------------------------------------------------------------------- |
| Name            | LingoesLDF                                                          |
| snake_case_name | lingoes_ldf                                                         |
| Description     | Lingoes Source (.ldf)                                               |
| Extensions      | `.ldf`                                                              |
| Read support    | Yes                                                                 |
| Write support   | Yes                                                                 |
| Single-file     | Yes                                                                 |
| Kind            | 📝 text                                                              |
| Sort-on-write   | default_no                                                          |
| Sort key        | (`headword_lower`)                                                  |
| Wiki            | [Lingoes](https://en.wikipedia.org/wiki/Lingoes)                    |
| Website         | [Lingoes.net](http://www.lingoes.net/en/dictionary/dict_format.php) |

### Read options

| Name     | Default | Type | Comment          |
| -------- | ------- | ---- | ---------------- |
| encoding | `utf-8` | str  | Encoding/charset |

### Write options

| Name      | Default | Type | Comment                       |
| --------- | ------- | ---- | ----------------------------- |
| newline   | `\n`    | str  | Newline string                |
| resources | `True`  | bool | Enable resources / data files |



### Dictionary Applications/Tools

| Name & Website                                                                     | License | Platforms |
| ---------------------------------------------------------------------------------- | ------- | --------- |
| [Lingoes Dictionary Creator](http://www.lingoes.net/en/dictionary/dict_format.php) | Unknown |           |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/lingoes_ldf.md <==
## Lingoes Source (.ldf)

### General Information

| Attribute       | Value                                                               |
| --------------- | ------------------------------------------------------------------- |
| Name            | LingoesLDF                                                          |
| snake_case_name | lingoes_ldf                                                         |
| Description     | Lingoes Source (.ldf)                                               |
| Extensions      | `.ldf`                                                              |
| Read support    | Yes                                                                 |
| Write support   | Yes                                                                 |
| Single-file     | Yes                                                                 |
| Kind            | 📝 text                                                              |
| Sort-on-write   | No (by default)                                                     |
| Sort key        | (`headword_lower`)                                                  |
| Wiki            | [Lingoes](https://en.wikipedia.org/wiki/Lingoes)                    |
| Website         | [Lingoes.net](http://www.lingoes.net/en/dictionary/dict_format.php) |

### Read options

| Name     | Default | Type | Comment          |
| -------- | ------- | ---- | ---------------- |
| encoding | `utf-8` | str  | Encoding/charset |

### Write options

| Name      | Default | Type | Comment                       |
| --------- | ------- | ---- | ----------------------------- |
| newline   | `\n`    | str  | Newline string                |
| resources | `True`  | bool | Enable resources / data files |

### Dictionary Applications/Tools

| Name & Website                                                                     | Source code | License | Platforms | Language |
| ---------------------------------------------------------------------------------- | ----------- | ------- | --------- | -------- |
| [Lingoes Dictionary Creator](http://www.lingoes.net/en/dictionary/dict_format.php) | ―           | Unknown |           |          |
